.. image:: https://badge.fury.io/py/django-csp.svg
   :target: https://pypi.python.org/pypi/django_csp

.. image:: https://github.com/mozilla/django-csp/actions/workflows/ci.yaml/badge.svg
   :target: https://github.com/mozilla/django-csp/actions/workflows/ci.yaml

==========
Django-CSP
==========

Django-CSP adds Content-Security-Policy_ headers to Django.

The code lives on GitHub_, where you can report Issues_.

The full documentation is available on ReadTheDocs_.

.. _Content-Security-Policy: http://www.w3.org/TR/CSP/
.. _GitHub: https://github.com/mozilla/django-csp
.. _Issues: https://github.com/mozilla/django-csp/issues
.. _ReadTheDocs: http://django-csp.readthedocs.org/
